#
# spec file for package python-gssapi
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-gssapi
Version:        1.8.2
Release:        3.1
Summary:        A Python interface to RFC 2743/2744 (plus common extensions)
License:        ISC
URL:            https://github.com/pythongssapi/python-gssapi
Source:         https://files.pythonhosted.org/packages/source/g/gssapi/gssapi-%{version}.tar.gz
Patch1:         https://github.com/pythongssapi/python-gssapi/commit/d9200d1018ac916b30433da23898c8c5fbde0f28.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module decorator}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module k5test}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  krb5-devel
BuildRequires:  python-rpm-macros
Requires:       python-decorator
%python_subpackages

%description
Python-GSSAPI provides both low-level and high level wrappers around the GSSAPI
C libraries. While it focuses on the Kerberos mechanism, it should also be
usable with other GSSAPI mechanisms.

%prep
%autosetup -p1 -n gssapi-%{version}
sed -i "s/'gssapi.tests'//" setup.py

mv gssapi/tests .

%build
export CFLAGS="%{optflags} -DHAS_GSSAPI_EXT_H -fno-strict-aliasing"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
mv gssapi gssapi_temp
%pytest_arch tests
mv gssapi_temp gssapi

%files %{python_files}
%{python_sitearch}/gssapi*
%doc README.rst
%license LICENSE.txt

%changelog
* Mon Aug 14 2023 Dirk Müller <dmueller@suse.com>
- add d9200d1018ac916b30433da23898c8c5fbde0f28.patch to
  improve cython 3.x interoperability
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Nov  8 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version to 1.8.2
  * Added Python 3.11 wheel - #303
  * Fix up doc link in README
  * Use just major version
  * Bump GHA actions to latest version
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version to 1.8.1 with Python 3.7 requires
  * Fix up build problems with latest change
  * Change sdist and build to use PEP517
  * Fix up doc references
  * More fixes for the release process
* Sat Sep 17 2022 John Vandenberg <jayvdb@gmail.com>
- Move tests out of runtime package
- Enable test suite
* Tue Feb 22 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.7.3
  - Fix up sha512sum file generation in the GitHub release asset
  - Added Python type annotation to classes and functions
- Update to 1.7.2:
  - Fix distutil deprecation on Python 3.10 by using setuptools
    instead
- Update to 1.7.0:
  - Add Kerberos specific GSS-API Extensions
  - Tidy up docs and turn warnings into errors
- Update to 1.6.14:
  - Enable specification of krb5-config via environment variable
  - Support for GSS_C_CHANNEL_BOUND_FLAG
  - Support for docs build with sphinx 4
  - Fix undefined variable in get_all_statuses()
  - Add support for str objects in the cred store dict
* Mon Feb  1 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.6.12:
  * Fix GSSAPI detection for macOS Big Sur (#235, #236)
  * Clarify how to disable detection (#234)
- Update to 1.6.11:
  * Fix build on FreeBSD (#232, #228)
  * On FreeBSD, prefer GSSAPI from ports if available (#232)
  * Support python >= 3.8 in test suite by dropping dependency on
    should_be (#215, #229)
  * Fix malformed S4U tests (#220, #229)
- Update to 1.6.10:
  * Provide python 3.9 Windows wheels (#226, #227)
  * Fix shlex.split on Windows (#223)
  * Removed six package and other older py cleanup values
    (#221, #222)
- Update to 1.6.9:
  * Raise exception on unknown usage (#202, #203)
  * Update tutorial to make server_name equal FQDN (#209)
  * Handle missing locale.LC_MESSAGES on Windows (#211)
- Update to 1.6.5:
  * There were no releases between 1.6.5 and 1.6.9 due to release
    pipeline issues with Github Actions.
  * Fix python_requires so that python-3.5 users hopefully
    don't get a version they can't use (#199, #198)
- Update to 1.6.4:
  * There was no v1.6.3 due to an incompatible sphinx extension
    change.
  * Fix missing substitution in inquire_property (#195, #196)
  * Fix DLL handling on Windows with workarounds (#193, #194, #197)
* Mon Mar 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Wed Mar  4 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.6.2
  * docu update
* Tue Aug 13 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.6.1
  * GSSAPI extension rfc4178 (set_neg_mechs) support
  * Expose mechanisms in the high-level API
* Wed Aug  7 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.6.0
  * no upstream changelog
* Fri May 10 2019 pgajdos@suse.com
- version update to 1.5.1
  * Remove warning about collections.abc usage for Python 3.7+ (#154)
* Mon May  7 2018 mimi.vx@gmail.com
- initial package
